#
#  - patch manipulating procedures -
#
#   Created:    07/00
#   Changed:    03/01 
#
########################################################################

##############################################################################
#
# Check whether values are modified 
#
proc CheckModified {var1 var2 op} {
global a33
	if { ($var2 != "Patch") && ($var2 != "Bank") && ($var2 != "saved") && ($var2 != "cancel")} {
		set a33(saved) 0 
		UpdateDisplay "PATCH: $a33(oldBank)-$a33(oldPatch) <MOD>" "$a33(name)"
	}
}

###############################################################################
#
# Delete variable trace 
#
proc DestroyTrace {} {
global a33
	trace vdelete a33 w "CheckModified"
}

###############################################################################
#
# Init variable trace 
#
proc InitTrace {} {
global a33
	DestroyTrace
	trace variable a33 w "CheckModified"
	set a33(saved) 1
	UpdateDisplay "PATCH: $a33(oldBank)-$a33(oldPatch)" "$a33(name)"
}

################################################################
#
# LoadPatch --
#
# Loads the selected patch 
#
# Arguments:  -
#
# Returns:    -
#
proc LoadPatch {} {
global a33

	DestroyTrace

	# highlight patch
	scan [.view.workspace.bp bbox $a33(Bank)-$a33(Patch)] "%s %s %s %s" x1 y1 x2 y2
	incr x1 -2
	incr y1 -1
	set x2 [expr $x1 + 60]
	incr y2 +1
	.view.workspace.bp delete marker
	.view.workspace.bp create rectangle $x1 $y1 $x2 $y2 -fill  #ffcc66 -tag marker
	.view.workspace.bp itemconfigure $a33(oldBank)-$a33(oldPatch) -fill #ffcc66
	.view.workspace.bp itemconfigure $a33(Bank)-$a33(Patch) -fill #000000
	.view.workspace.bp lower marker $a33(Bank)-$a33(Patch)

	set a33(oldBank) $a33(Bank)
	set a33(oldPatch) $a33(Patch)

	set patchname $a33(Bank)-$a33(Patch)
	LoadMap $patchname
	Map2Patch $patchname

	# preapare to check whether modified
	InitTrace

	update
}

##############################################################################
#
# SavePatch --
#
# Saves the current patch 
#
# Arguments:  -
#
# Returns:    -
#
proc SavePatch {} {
global a33

	set patchname $a33(Bank)-$a33(Patch)
	Patch2Map $patchname
	SaveMap $patchname

	# preapare to check whether modified
	InitTrace
}

################################################################
#
# CopyPatch --
#
# Copy current patch data to clipboard. 
#
# Arguments:   -
#
# Returns:    -
#
proc CopyPatch  {} {
global a33 clipboard

	array set clipboard {}
	
	# deny list
	set deny "Bank Patch oldPatch oldBank address"

	# copy current map
	foreach name [array names a33] {
		if {![regexp $name $deny]} {
			set clipboard($name) $a33($name)			
		}
	}
	update
	
}

################################################################
#
# PastePatch --
#
# Paste clipboard to the current patch. 
#
# Arguments:   -
#
# Returns:    -
#
proc PastePatch  {} {
global a33 clipboard

	# copy current clipboard
	foreach name [array names clipboard] {
		set a33($name) $clipboard($name)
	}
	update
	
}

################################################################
#
# DeletePatch --
#
# Delete the current patch parameters and replace it with
# initial values. 
#
# Arguments:   -
#
# Returns:    -
#
proc DeletePatch  {} {
global a33 projdir

	set patchname $a33(Bank)-$a33(Patch)
	set filename ${patchname}.cfg

	set msg "Do you really want do delete patch $patchname?"
	set rc [tk_messageBox -title Init -message $msg -type yesno]
	if { $rc == "no" } {return}

	# delete config file
	file delete $filename
	LoadPatch  
	
	update
}


